@@ -1,6 +1,6 @@
 /*
  * happydigger - program for cataloging archaeological finds
- * Copyright (C) 2004, 2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2004, 2005, 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
 #include <gtk/gtk.h>
@@ -23,7 +23,7 @@
 
 #include "callbacks.h"
 #include "interface.h"
-#include "support.h"
+#include "utils.h"
 #include "preferences.h"
 #include "gui_utils.h"
 
@@ -95,6 +95,8 @@ exit_program                           (GtkWidget       *widget,
 	savepreferences ();
 	g_free (state.imageloaddir);
 	g_free (state.table);
+	g_free (state.webmapdir);
+	g_free (state.sortby);
 	gtk_main_quit ();
 	return FALSE;
 }
@@ -207,4 +209,3 @@ on_image2entry_changed                 (GtkEditable     *editable,
 		state.imageloaddir = g_strdup (imagepath);
 	}
 }
-
