@@ -564,15 +564,15 @@ on_sortcombo_changed (GtkComboBox *combo, gpointer user_data)
 	preferences.sortby = item;
 	switch (item)
 	{
-		case 0: state.sortby = g_strdup ("find");	break;
+		case 0: state.sortby = g_strdup ("find"); break;
 		case 1: state.sortby = g_strdup ("nr");	break;
-		case 2: state.sortby = g_strdup ("description");	break;
-		case 3: state.sortby = g_strdup ("type");	break;
-		case 4: state.sortby = g_strdup ("material");	break;
-		case 5: state.sortby = g_strdup ("period");	break;
-		case 6: state.sortby = g_strdup ("notes");	break;
-		case 7: state.sortby = g_strdup ("date");	break;
-		case 8: state.sortby = g_strdup ("value");	break;
+		case 2: state.sortby = g_strdup ("description"); break;
+		case 3: state.sortby = g_strdup ("type"); break;
+		case 4: state.sortby = g_strdup ("material"); break;
+		case 5: state.sortby = g_strdup ("period"); break;
+		case 6: state.sortby = g_strdup ("notes"); break;
+		case 7: state.sortby = g_strdup ("date"); break;
+		case 8: state.sortby = g_strdup ("value"); break;
 		case 9: state.sortby = g_strdup ("reference"); break;
 		case 10: state.sortby = g_strdup ("finddate"); break;
 		case 11: state.sortby = g_strdup ("lcoation"); break;
@@ -603,20 +603,20 @@ on_webbutton_clicked                   (GtkButton       *button,
 
 	sortlabel = gtk_label_new (_("Sort by"));
 	sortitems = gtk_combo_box_new_text ();
-	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), "Find");
-	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), "Number");
-	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), "Description");
-	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), "Type");
-	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), "Material");
-	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), "Period");
-	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), "Findnotes");
-	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), "Date");
-	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), "Value");
-	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), "Reference");
-	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), "Find date");
-	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), "Location");
-	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), "Coordinates");
-	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), "Spotnotes");
+	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), _("Record"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), _("Number"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), _("Description"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), _("Type"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), _("Material"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), _("Period"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), _("Findnotes"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), _("Date"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), _("Value"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), _("Reference"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), _("Find date"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), _("Location"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), _("Coordinates"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX(sortitems), _("Spotnotes"));
 	gtk_combo_box_set_active (GTK_COMBO_BOX (sortitems), preferences.sortby);
 	g_signal_connect ((gpointer) sortitems, "changed",
 		G_CALLBACK (on_sortcombo_changed), NULL);
