@@ -152,7 +152,7 @@ create_window (void)
   accel_group = gtk_accel_group_new ();
 
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  gtk_widget_set_size_request (window, 680, -1);
+//  gtk_widget_set_size_request (window, 680, -1);
   gtk_window_set_title (GTK_WINDOW (window), _("happydigger"));
   window_icon_pixbuf = create_pixbuf ("happydigger.png");
   if (window_icon_pixbuf)
@@ -669,7 +669,7 @@ create_window (void)
   image1button = gtk_button_new ();
   gtk_widget_show (image1button);
   gtk_box_pack_start (GTK_BOX (hbox17), image1button, FALSE, FALSE, 0);
-  gtk_widget_set_size_request (image1button, -1, 27);
+//  gtk_widget_set_size_request (image1button, -1, 27);
   gtk_tooltips_set_tip (tooltips, image1button, _("Select first image"), NULL);
 
   image24 = gtk_image_new_from_stock ("gtk-open", GTK_ICON_SIZE_BUTTON);
@@ -688,7 +688,7 @@ create_window (void)
   image2button = gtk_button_new ();
   gtk_widget_show (image2button);
   gtk_box_pack_start (GTK_BOX (hbox18), image2button, FALSE, FALSE, 0);
-  gtk_widget_set_size_request (image2button, -1, 27);
+//  gtk_widget_set_size_request (image2button, -1, 27);
   gtk_tooltips_set_tip (tooltips, image2button, _("Select second image"), NULL);
 
   image25 = gtk_image_new_from_stock ("gtk-open", GTK_ICON_SIZE_BUTTON);
